@@ -1,27 +1,46 @@
-import warnings
-
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 from django.db import models, router
 from django.db.models.fields.related_descriptors import ForwardManyToOneDescriptor
 
 from isapilib.api.models import UserAPI  # noqa keep this
+from isapilib.logging import logger
 
 
 class DynamicManager(models.Manager):
     def get_queryset(self):
         queryset = super().get_queryset()
+        meta = queryset.model._meta
+        db_table_options = meta.db_table
 
-        if isinstance(queryset.model._meta.db_table, dict):
-            using = router.db_for_write(None)
-            version = settings.DATABASES[using]['INTELISIS_VERSION']
-            db_table_options = queryset.model._meta.db_table
+        if not isinstance(db_table_options, dict):
+            return queryset
 
-            try:
-                queryset.model._meta.db_table = db_table_options[version]
-            except KeyError:
-                raise Exception(f'The model {queryset.model} does not have a table for version {version}')
+        name = queryset.model.__name__
+        using = router.db_for_write(None)
+        version = settings.DATABASES[using]['INTELISIS_VERSION']
 
-        return queryset
+        try:
+            db_table_options = {int(k): v for k, v in db_table_options.items()}
+        except ValueError:
+            raise ImproperlyConfigured(f'{name} does not have a valid db_table definition, expected {{int:str}}')
+
+        db_table_default = getattr(meta, 'db_table_default', 6000)
+
+        logger.debug('Dynamic table resolution for model %s using=%s version=%s default=%s options=%s',
+                     name, using, version, db_table_default, db_table_options)
+
+        if table_name := db_table_options.get(version):
+            meta.db_table = table_name
+            logger.debug('Resolved table for %s using version %s → %s', name, version, table_name)
+            return queryset
+
+        if table_name := db_table_options.get(db_table_default):
+            meta.db_table = table_name
+            logger.debug('Resolved table for %s using default %s → %s', name, db_table_default, table_name)
+            return queryset
+
+        raise Exception(f'The model {name} does not have a table for version {version} using connection {using}')
 
 
 class BaseModel(models.Model):
@@ -32,11 +51,13 @@ class BaseModel(models.Model):
             if isinstance(field, models.CharField):
                 val = str(getattr(self, field.name) or '')
                 if val and field.max_length < len(val):
-                    setattr(self, field.name, val[:field.max_length])
-                    warnings.warn(
-                        f'The value of the field "{self.__class__.__name__}.{field.name}" was truncated to {field.max_length} characters')
+                    truncated = val[:field.max_length]
+                    setattr(self, field.name, truncated)
+                    logger.warning('Value field %s.%s was truncated to %s characters (%r:%r)',
+                                   self.__class__.__name__, field.name, field.max_length, val, truncated)
 
-        query = self.__class__.objects.filter(pk=self.pk)
+        using = using or router.db_for_write(None)
+        query = self.__class__.objects.using(using).filter(pk=self.pk)
 
         if self.pk and query.exists():
             fields = update_fields or [
