@@ -1,5 +1,15 @@
 import sys
 
+from django.conf import settings
+
+
+def get_default_user():
+    return getattr(settings, 'INTELISIS_USER', 'SOPDESA')
+
+
+def get_dealer_field():
+    return getattr(settings, 'DEALER_FIELD', 'dealerID')
+
 
 def to_bool(s):
     if isinstance(s, bool):
@@ -16,7 +26,10 @@ def to_bool(s):
 
 
 def get_sucursal_from_request(request):
-    return int(request.user.id_intelisis or 0)
+    try:
+        return request.user.branch.sucursal
+    except Exception as e:
+        return 0
 
 
 def is_test():
