@@ -142,10 +142,17 @@ class ExecutionSP(ExecutionQuery):
 
     def execute(self, only_output=True):
         results = super().execute()
+        results = [i[0] for i in results]
+
+        if isinstance(results, (list, tuple)):
+            if len(results) == 0: return None
+
         if only_output:
-            last_line = results[-1][0]
-            if last_line[0] == 'OUTPUT':
-                return last_line[1:]
+            for result in results:
+                if result[0] == 'OUTPUT':
+                    return result[1:]
+            return None
+
         return results
 
 
@@ -206,6 +213,16 @@ def get_param_sucursal(sucursal, clave, default=None, using=None):
     return getattr(valor, 'valor', default)
 
 
+def verify_col(table, column, using=None) -> bool:
+    try:
+        query = f"SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = '{table}' AND COLUMN_NAME = '{column}'"
+        result = execute_query(query, using)
+        exists = result[0][0][0]
+        return bool(exists)
+    except IndexError:
+        return False
+
+
 def get_utc_offset(using=None) -> int:
     result = execute_query('SELECT DATEPART(TZOFFSET, SYSDATETIMEOFFSET())', [], using=using)[0][0][0]
     return int(result)
