@@ -1,6 +1,6 @@
 from django.db import models
-
 from isapilib.core.models import BaseModel, DummyForeignKey
+from isapilib.core.utilities import get_default_user
 from isapilib.mixin.cte import CteMixin
 from isapilib.mixin.venta import VentaMixin
 from isapilib.mixin.vin import VinMixin
@@ -33,7 +33,7 @@ class Art(BaseModel):
     tipo = models.CharField(db_column='Tipo', max_length=20)
     precio_lista = models.DecimalField(db_column='PrecioLista', max_digits=19, decimal_places=4, blank=True, null=True)
     estatus = models.CharField(db_column='Estatus', max_length=15, default='ALTA')
-    usuario = models.CharField(db_column='Usuario', max_length=10, blank=True, null=True)
+    usuario = models.CharField(db_column='Usuario', max_length=10, default=get_default_user)
     precio2 = models.DecimalField(db_column='Precio2', max_digits=19, decimal_places=4, blank=True, null=True)
     precio3 = models.DecimalField(db_column='Precio3', max_digits=19, decimal_places=4, blank=True, null=True)
     precio4 = models.DecimalField(db_column='Precio4', max_digits=19, decimal_places=4, blank=True, null=True)
@@ -211,7 +211,7 @@ class Cte(BaseModel, CteMixin):
     fecha3 = models.DateTimeField(db_column='Fecha3', blank=True, null=True)
     fecha4 = models.DateTimeField(db_column='Fecha4', blank=True, null=True)
     fecha5 = models.DateTimeField(db_column='Fecha5', blank=True, null=True)
-    usuario = models.CharField(db_column='Usuario', max_length=10, blank=True, null=True)
+    usuario = models.CharField(db_column='Usuario', max_length=10, default=get_default_user)
     fiscal_regimen = models.CharField(db_column='FiscalRegimen', max_length=30, blank=True, null=True)
     contactar = models.CharField(db_column='Contactar', max_length=30, blank=True, null=True)
 
@@ -361,6 +361,20 @@ class VinAccesorio(BaseModel):
         db_table = 'VinAccesorio'
 
 
+class Usuario(BaseModel):
+    usuario = models.CharField(db_column='Usuario', primary_key=True, max_length=10)
+    nombre = models.CharField(db_column='Nombre', max_length=100)
+    sucursal = models.IntegerField(db_column='Sucursal')
+    def_agente = DummyForeignKey(Agente, db_column='DefAgente', to_field='agente', on_delete=models.PROTECT,
+                                 related_name='usuarios', blank=True, null=True)
+    email = models.CharField(db_column='eMail', max_length=50)
+    estatus = models.CharField(db_column='Estatus', max_length=15, default='ALTA')
+
+    class Meta:
+        managed = False
+        db_table = 'Usuario'
+
+
 class Venta(BaseModel, VentaMixin):
     id = models.AutoField(db_column='ID', primary_key=True, unique=True)
     agente = DummyForeignKey(Agente, db_column='Agente', to_field='agente', on_delete=models.PROTECT,
@@ -375,7 +389,8 @@ class Venta(BaseModel, VentaMixin):
     uen = models.IntegerField(db_column='UEN', blank=True, null=True)
     moneda = models.CharField(db_column='Moneda', max_length=10, default='Pesos')
     tipo_cambio = models.FloatField(db_column='TipoCambio', default=1, blank=True, null=True)
-    usuario = models.CharField(db_column='Usuario', max_length=10, blank=True, null=True)
+    usuario = DummyForeignKey(Usuario, db_column='Usuario', to_field='usuario', on_delete=models.PROTECT,
+                              related_name='ventas', default=get_default_user)
     referencia = models.CharField(db_column='Referencia', max_length=50, blank=True, null=True)
     observaciones = models.CharField(db_column='Observaciones', max_length=100, blank=True, null=True)
     estatus = models.CharField(db_column='Estatus', default='SINAFECTAR', max_length=15, blank=True, null=True)
@@ -500,6 +515,15 @@ class VentaD(BaseModel):
         unique_together = (('id', 'renglon', 'renglon_sub'),)
 
 
+class CuentasPorCobrar(BaseModel):
+    mov = models.CharField(db_column='Mov', max_length=20)
+    mov_id = models.CharField(db_column='MovID', max_length=20, blank=True, null=True)
+
+    class Meta:
+        managed = False
+        db_table = 'Cxc'
+
+
 class TipoOrdenOperacion(BaseModel):
     interfaz = models.CharField(db_column='Interfaz', max_length=100)
     operacion_planta = models.CharField(db_column='OrdenOperacionPlanta', max_length=50)
@@ -549,7 +573,7 @@ class VentaTraspasarArticulos(BaseModel):
     aplica_mov_id = models.CharField(db_column='AplicaMovID', max_length=20, blank=True, null=True)
     sin_validar_reservado = models.BooleanField(db_column='SinValidarReservado', default=False)
     paquete = models.IntegerField(db_column='Paquete', blank=True, null=True)
-    usuario = models.CharField(db_column='Usuario', max_length=20, default='SOPDESA', blank=True, null=True)
+    usuario = models.CharField(db_column='Usuario', max_length=20, default=get_default_user)
     contrasena = models.CharField(db_column='Contrasena', max_length=40, blank=True, null=True)
     descuento_linea = models.DecimalField(db_column='DescuentoLinea', max_digits=19, decimal_places=4, blank=True,
                                           null=True)
@@ -624,8 +648,9 @@ class InterfacesPredefinidas(BaseModel):
 
 
 class InterfacesPredefinidasDEmpresa(BaseModel):
-    interfaz_id = DummyForeignKey(InterfacesPredefinidas, db_column='ID', to_field='interfaz_id', on_delete=models.PROTECT,
-                         related_name='interfaces')
+    interfaz_id = DummyForeignKey(InterfacesPredefinidas, db_column='ID', to_field='interfaz_id',
+                                  on_delete=models.PROTECT,
+                                  related_name='interfaces')
     renglon_id = models.IntegerField(db_column='RenglonID', blank=True, null=True)
     clave = models.CharField(db_column='Clave', max_length=50)
     descripcion = models.CharField(db_column='Descripcion', max_length=100)
