@@ -14,6 +14,17 @@ from rest_framework.test import APIClient
 
 from isapilib.api.models import ApiLogs
 from isapilib.auth.permissions import IsapilibPermission
+from isapilib.core.utilities import get_dealer_field
+
+
+def set_headers(dealer, fn):
+    def wrapper(*args, **kwargs):
+        dealer_field = get_dealer_field()
+        headers = kwargs.get('headers', {})
+        headers[dealer_field] = dealer
+        return fn(*args, **kwargs, headers=headers)
+
+    return wrapper
 
 
 class IsapiTestCase(unittest.TestCase):
@@ -21,6 +32,8 @@ class IsapiTestCase(unittest.TestCase):
     auth_data: Union[dict, None] = None
     context = {}
 
+    dealer = None
+
     class AUTHMETHODS:
         JWT = 'jwt'
         OAUTH2 = 'oauth2'
@@ -31,9 +44,21 @@ class IsapiTestCase(unittest.TestCase):
         self.client = APIClient()
         self.factory = RequestFactory()
 
+        if self.dealer is not None:
+            dealer_field = get_dealer_field()
+            setattr(self.client, 'put', set_headers(self.dealer, self.client.put))
+            setattr(self.client, 'get', set_headers(self.dealer, self.client.get))
+            setattr(self.client, 'post', set_headers(self.dealer, self.client.post))
+            setattr(self.client, 'delete', set_headers(self.dealer, self.client.delete))
+
+            setattr(settings, dealer_field, self.dealer)
+
         if isinstance(self.auth_data, dict):
             user = get_user_model()
-            self.user = user.objects.get(username=self.auth_data['user'])
+            try:
+                self.user = user.objects.get(username=self.auth_data['user'])
+            except user.DoesNotExist:
+                raise Exception(f'El usuario no existe {self.auth_data['user']}')
             self.authenticate()
 
             factory = RequestFactory()
@@ -78,24 +103,27 @@ class IsapiTestCase(unittest.TestCase):
             self.application = access_token.application
 
         self.token = access_token.token
-        self.client.credentials(HTTP_AUTHORIZATION='Bearer ' + self.token)
+        prefix = self.auth_data.get('token_prefix', 'Bearer')
+        self.client.credentials(HTTP_AUTHORIZATION=f'{prefix} ' + self.token)
 
     def auth_jwt(self):
         from rest_framework_simplejwt.tokens import RefreshToken
 
         refresh = RefreshToken.for_user(self.user)
         self.token = str(refresh.access_token)
-        self.client.credentials(HTTP_AUTHORIZATION='Bearer ' + self.token)
+        prefix = self.auth_data.get('token_prefix', 'Bearer')
+        self.client.credentials(HTTP_AUTHORIZATION=f'{prefix} ' + self.token)
 
     def auth_authtoken(self):
         from rest_framework.authtoken.models import Token
 
         self.token, _ = Token.objects.get_or_create(user=self.user)
-        self.client.credentials(HTTP_AUTHORIZATION='Token ' + self.token.key)
+        prefix = self.auth_data.get('token_prefix', 'Token')
+        self.client.credentials(HTTP_AUTHORIZATION=f'{prefix} ' + self.token.key)
 
     def assertResponse(self, request, response, status_code=status.HTTP_200_OK):
         self.assertEqual(
-            response.status_code,
             status_code,
+            response.status_code,
             f'\nURL: {response.request['PATH_INFO']}\nREQUEST: {request}\nRESPONSE: {response.content}'
         )
