@@ -1,5 +1,6 @@
 from datetime import datetime, timedelta, UTC
 
+from isapilib.core.exceptions import RequestError
 from isapilib.external.utilities import get_utc_offset
 from isapilib.models import Venta
 
@@ -16,7 +17,7 @@ class DateAfterTodayValidator:
         current_date = datetime.now(UTC) + timedelta(minutes=get_utc_offset())
         try:
             if fecha_requerida < current_date:
-                raise Exception('The date must be after the current date')
+                raise RequestError('The date must be after the current date')
         except TypeError as e:
             raise Exception(f'[{fecha_requerida.tzinfo}, {current_date.tzinfo}] - {e}')
 
@@ -34,5 +35,6 @@ class NoDuplicateAppointmentsValidator:
             'hora_recepcion': value['hora_recepcion'],
             'estatus': 'CONFIRMAR'
         }
+
         if Venta.objects.filter(**filters).exists():
-            raise Exception('This appointment has already been scheduled')
+            raise RequestError('This appointment has already been scheduled')
