@@ -1,9 +1,14 @@
 from django.conf import settings
 from django.http import HttpResponse
+from importlib.metadata import version
 
 
-def index(request):
+def index(_):
+    interfaz_name = getattr(settings, 'INTERFAZ_NAME')
     url_doc = getattr(settings, 'URL_DOCUMENTATION', '')
+    if interfaz_name: interfaz_name = f'<i>{interfaz_name}</i>'
+
+    isapilib_version = version("isapilib")
 
     return HttpResponse(f'''
         <style>
@@ -38,12 +43,27 @@ def index(request):
             a:hover {{
                 transform: scale(1.3);
             }}
+
+            i {{
+                font-size: 30%;
+                margin-bottom: 1.5vh;
+            }}
+
+            .version {{
+                position: absolute;
+                font-style: normal;
+                font-size: 15%;
+                opacity: 20%;
+                margin: 1vw;
+                bottom: 0;
+                right: 0;
+            }}
         </style>
 
         <div>
             <p>Intelisis</p>
-            {
-    f'<a href="{url_doc}">Documentation</a>' if url_doc != '' else ''
-    }
+            {interfaz_name}
+            {f'<a href="{url_doc}">Documentation</a>' if url_doc != '' else ''}
+            <i class="version">Version {isapilib_version}</i>
         </div>
     ''')
